Support Reticulum - Reticulum Network Stack 0.7.8 beta documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# Support Reticulum

You can help support the continued development of open, free and private communications systems by donating, providing feedback and contributing code and learning resources.

## Donations

Donations are gratefully accepted via the following channels:

    Monero:
    84FpY1QbxHcgdseePYNmhTHcrgMX4nFfBYtz2GKYToqHVVhJp8Eaw1Z1EedRnKD19b3B8NiLCGVxzKV17UMmmeEsCrPyA5w

    Ethereum:
    0x81F7B979fEa6134bA9FD5c701b3501A2e61E897a

    Bitcoin:
    3CPmacGm34qYvR6XWLVEJmi2aNe3PZqUuq

    Ko-Fi:
    https://ko-fi.com/markqvist

Are certain features in the development roadmap are important to you or your organisation? Make them a reality quickly by sponsoring their implementation.

## Provide Feedback

All feedback on the usage, functioning and potential dysfunctioning of any and all components of the system is very valuable to the continued development and improvement of Reticulum. Absolutely no automated analytics, telemetry, error reporting or statistics is collected and reported by Reticulum under any circumstances, so we rely on old-fashioned human feedback.

## Contribute Code

Join us on the GitHub repository to report issues, suggest functionality and contribute code to Reticulum.